@@ -8,25 +8,25 @@ knitr::opts_chunk$set(
 library(metapower)
 
 ## -----------------------------------------------------------------------------
-my_power <- mpower(effect_size = .25, sample_size = 20, k = 30, es_type = "d")
+my_power <- mpower(effect_size = .2, sample_size = 20, k = 10, es_type = "d")
 
 ## -----------------------------------------------------------------------------
 print(my_power)
 
 ## ----fig.height=7, fig.width=7, dpi = 300,out.width = "100%", out.height = "100%"----
-power_plot(my_power)
+plot_mpower(my_power)
 
 ## -----------------------------------------------------------------------------
-str(my_power$df)
+str(my_power$power_range)
 
 ## -----------------------------------------------------------------------------
-(homogen_power <- mpower(effect_size = .25, sample_size = 20, k = 30, es_type = "d", sd = 3))
+(homogen_test_power <- homogen_power(effect_size = .25, sample_size = 20, k = 30, es_type = "d"))
 
 ## ----fig.height=7, fig.width=7, dpi = 300,out.width = "100%", out.height = "100%"----
-homogen_power_plot(homogen_power)
+plot_homogen_power(homogen_test_power)
 
 ## -----------------------------------------------------------------------------
-my_mod <- mod_power(n_groups = 2, 
+my_mod <- subgroup_power(n_groups = 2, 
                     effect_sizes = c(.2,.5), 
                     sample_size = 20,
                     k = 30,
